Snapshot<T> constructor
Snapshot<T> (
- T oldValue,
- T newValue
Creates a new snapshot containing both old and new values.
This is typically created internally by Reactive and Computed instances when a value changes, and then passed to listeners and effect callbacks.
Implementation
Snapshot(this.oldValue, this.newValue);